@@ -6,6 +6,8 @@ import re
 import socket
 import socks
 import importlib
+import prettytable
+from termcolor import colored
 from queue import Queue
 from urllib.parse import urlsplit
 
@@ -13,7 +15,7 @@ from pocsuite3.lib.core.clear import remove_extra_log_message
 from pocsuite3.lib.core.common import boldify_message, check_file, get_file_items, parse_target, \
     get_public_type_members, data_to_stdout
 from pocsuite3.lib.core.common import check_path, extract_cookies
-from pocsuite3.lib.core.common import get_local_ip, desensitization
+from pocsuite3.lib.core.common import get_local_ip, desensitization, get_host_ip
 from pocsuite3.lib.core.common import single_time_warn_message
 from pocsuite3.lib.core.common import OrderedSet
 from pocsuite3.lib.core.convert import stdout_encode
@@ -27,7 +29,7 @@ from pocsuite3.lib.core.enums import HTTP_HEADER, CUSTOM_LOGGING, PROXY_TYPE
 from pocsuite3.lib.core.exception import PocsuiteSyntaxException, PocsuiteSystemException, PocsuiteHeaderTypeException
 from pocsuite3.lib.core.log import FORMATTER
 from pocsuite3.lib.core.register import load_file_to_module
-from pocsuite3.lib.core.settings import DEFAULT_USER_AGENT, DEFAULT_LISTENER_PORT, CMD_PARSE_WHITELIST
+from pocsuite3.lib.core.settings import DEFAULT_LISTENER_PORT, CMD_PARSE_WHITELIST
 from pocsuite3.lib.core.statistics_comparison import StatisticsComparison
 from pocsuite3.lib.core.update import update
 from pocsuite3.lib.parse.cmd import DIY_OPTIONS
@@ -75,21 +77,6 @@ def _set_http_user_agent():
     set user-agent
     :return:
     '''
-
-    conf.http_headers[HTTP_HEADER.USER_AGENT] = DEFAULT_USER_AGENT
-
-    if conf.random_agent:
-        uapath = os.path.join(paths.POCSUITE_DATA_PATH, 'user-agents.txt')
-        if os.path.exists(uapath):
-            with open(uapath) as f:
-                agents = f.read().split("\n")
-                if len(agents) == 1 and "" in agents:
-                    logger.error("user-agents file is empty will use default")
-                else:
-                    conf.agents = agents
-        else:
-            logger.error("user-agents file not fond will use default")
-
     if conf.agent:
         conf.http_headers[HTTP_HEADER.USER_AGENT] = conf.agent
 
@@ -244,6 +231,7 @@ def _set_multiple_targets():
     if conf.dork_quake:
         conf.plugins.append('target_from_quake')
 
+
 def _set_task_queue():
     if kb.registered_pocs and kb.targets:
         for poc_module in kb.registered_pocs:
@@ -281,14 +269,18 @@ def _set_threads():
 
 
 def _set_connect_back():
-    ips = get_local_ip(all=True)
-    if ips:
-        kb.data.local_ips = ips
     if conf.mode == "shell" and conf.connect_back_host is None:
+        wan_ipv4 = get_host_ip()
+        kb.data.local_ips = get_local_ip(all=True)
         data_to_stdout("[i] pocsusite is running in shell mode, you need to set connect back host:\n")
         message = '----- Local IP Address -----\n'
         for i, ip in enumerate(kb.data.local_ips):
-            message += "{0}    {1}\n".format(i, desensitization(ip) if conf.ppt else ip)
+            v = ip
+            if conf.ppt:
+                v = desensitization(v)
+            if ip == wan_ipv4:
+                v = colored(f'{v}    *wan*', 'green')
+            message += "{0}    {1}\n".format(i, v)
         data_to_stdout(message)
         while True:
             choose = None
@@ -504,7 +496,6 @@ def _set_conf_attributes():
     conf.referer = None
     conf.agent = None
     conf.headers = None
-    conf.random_agent = None
     conf.proxy = None
     conf.proxy_cred = None
     conf.proxies = {}
@@ -512,7 +503,6 @@ def _set_conf_attributes():
     conf.retry = 0
     conf.delay = 0
     conf.http_headers = {}
-    conf.agents = [DEFAULT_USER_AGENT]  # When loading from the plug-in, if the data source has no default value, it needs to be processed
     conf.login_user = None
     conf.login_pass = None
     conf.shodan_token = None
@@ -557,6 +547,8 @@ def _set_conf_attributes():
     conf.rule = False
     conf.rule_req = False
     conf.rule_filename = None
+    conf.show_options = False
+    conf.enable_tls_listener = False
 
 
 def _set_kb_attributes(flush_all=True):
@@ -688,6 +680,8 @@ def _init_target_from_poc_dork():
                 target_source = i
                 break
         # fetch target from target source, add it to kb.targets
+        if not target_source:
+            continue
         conf.dork = poc_class.dork[target_source]
         plugin_name = f'target_from_{target_source}'
         importlib.import_module(f'pocsuite3.plugins.{plugin_name}')
@@ -696,6 +690,25 @@ def _init_target_from_poc_dork():
                 plugin.init()
 
 
+def _show_pocs_modules_options():
+    if not conf.show_options:
+        return
+    for module_name, poc_class in kb.registered_pocs.items():
+        module_options = poc_class.options
+        tb = prettytable.PrettyTable(
+            ['Name', 'Current settings', 'Type', 'Description'])
+        # add target option
+        for name, opt in module_options.items():
+            value = opt.value
+            if opt.require and value == '':
+                value = colored('*require*', 'red')
+            tb.add_row([name, value, opt.type, opt.description])
+        data_to_stdout(f'\nModule ({module_name}) options:\n')
+        data_to_stdout(tb.get_string())
+        data_to_stdout('\n')
+    exit()
+
+
 def init():
     """
     Set attributes into both configuration and knowledge base singletons
@@ -715,6 +728,7 @@ def init():
     _set_plugins()
     _init_targets_plugins()
     _init_pocs_plugins()
+    _show_pocs_modules_options()
     _init_target_from_poc_dork()
     _set_task_queue()
     _init_results_plugins()
