@@ -54,9 +54,7 @@ def cmd_line_parser(argv=None):
         request.add_argument("--cookie", dest="cookie", help="HTTP Cookie header value")
         request.add_argument("--host", dest="host", help="HTTP Host header value")
         request.add_argument("--referer", dest="referer", help="HTTP Referer header value")
-        request.add_argument("--user-agent", dest="agent", help="HTTP User-Agent header value")
-        request.add_argument("--random-agent", dest="random_agent", action="store_true", default=False,
-                             help="Use randomly selected HTTP User-Agent header value")
+        request.add_argument("--user-agent", dest="agent", help="HTTP User-Agent header value (default random)")
         request.add_argument("--proxy", dest="proxy", help="Use a proxy to connect to the target URL")
         request.add_argument("--proxy-cred", dest="proxy_cred", help="Proxy authentication credentials (name:password)")
         request.add_argument("--timeout", dest="timeout", help="Seconds to wait before timeout connection (default 30)")
@@ -64,7 +62,7 @@ def cmd_line_parser(argv=None):
         request.add_argument("--delay", dest="delay", help="Delay between two request of one thread")
         request.add_argument("--headers", dest="headers", help="Extra headers (e.g. \"key1: value1\\nkey2: value2\")")
         # Account options
-        group = parser.add_argument_group("Account", "Telnet404、Shodan、CEye、Fofa account options")
+        group = parser.add_argument_group("Account", "Telnet404, Shodan, CEye, Fofa account options")
         group.add_argument("--login-user", dest="login_user", help="Telnet404 login user")
         group.add_argument("--login-pass", dest="login_pass", help="Telnet404 login password")
         group.add_argument("--shodan-token", dest="shodan_token", help="Shodan token")
@@ -74,7 +72,7 @@ def cmd_line_parser(argv=None):
         group.add_argument("--censys-uid", dest="censys_uid", help="Censys uid")
         group.add_argument("--censys-secret", dest="censys_secret", help="Censys secret")
         # Modules options
-        modules = parser.add_argument_group("Modules", "Modules(Seebug、Zoomeye、CEye、Fofa、Quake Listener) options")
+        modules = parser.add_argument_group("Modules", "Modules(Seebug, Zoomeye, CEye, Fofa, Quake, Listener) options")
         modules.add_argument("--dork", dest="dork", action="store", default=None,
                              help="Zoomeye dork used for search.")
         modules.add_argument("--dork-zoomeye", dest="dork_zoomeye", action="store", default=None,
@@ -88,7 +86,7 @@ def cmd_line_parser(argv=None):
         modules.add_argument("--dork-quake", dest="dork_quake", action="store", default=None,
                              help="Quake dork used for search.")
         modules.add_argument("--max-page", dest="max_page", type=int, default=1,
-                             help="Max page used in ZoomEye API(10 targets/Page).")
+                             help="Max page used in search API.")
         modules.add_argument("--search-type", dest="search_type", action="store", default='host',
                              help="search type used in ZoomEye API, web or host")
         modules.add_argument("--vul-keyword", dest="vul_keyword", action="store", default=None,
@@ -99,6 +97,8 @@ def cmd_line_parser(argv=None):
                              help="Connect back host for target PoC in shell mode")
         modules.add_argument("--lport", dest="connect_back_port", action="store", default=None,
                              help="Connect back port for target PoC in shell mode")
+        modules.add_argument("--tls", dest="enable_tls_listener", action="store_true", default=False,
+                             help="Enable TLS listener in shell mode")
         modules.add_argument("--comparison", dest="comparison", help="Compare popular web search engines",
                              action="store_true",
                              default=False)
@@ -125,7 +125,7 @@ def cmd_line_parser(argv=None):
         optimization.add_argument("--pcap", dest="pcap", action="store_true", default=False,
                                   help="use scapy capture flow")
         optimization.add_argument("--rule", dest="rule", action="store_true", default=False,
-                                  help="export rules, default export reqeust and response")
+                                  help="export suricata rules, default export reqeust and response")
         optimization.add_argument("--rule-req", dest="rule_req", action="store_true", default=False,
                                   help="only export request rule")
         optimization.add_argument("--rule-filename", dest="rule_filename", action="store", default=False,
@@ -133,7 +133,7 @@ def cmd_line_parser(argv=None):
         # Diy options
         diy = parser.add_argument_group("Poc options", "definition options for PoC")
         diy.add_argument("--options", dest="show_options", action="store_true", default=False,
-                                  help="Show all definition options")
+                         help="Show all definition options")
 
         for line in argv:
             if line.startswith("--"):
